@@ -1,11 +1,10 @@
+import logging
 import multiprocessing
 
 from gensim.models import Word2Vec
 from gensim.models.word2vec import LineSentence
 
-from ...utils import get_logger
-
-log = get_logger(__name__)
+log = logging.getLogger(__name__)
 
 
 def train(
