@@ -1,11 +1,11 @@
+import logging
 from typing import Optional
 
 import editdistance
 
 from ...training.stemming import StemDict, StemGenerator
-from ...utils import get_logger
 
-log = get_logger(__name__)
+log = logging.getLogger(__name__)
 
 
 class DefaultStemGenerator(StemGenerator):
